Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(47)

Unified Diff: content/renderer/clipboard_client.h

Issue 17420005: Move the following clipboard files from webkit\glue to webkit\renderer. These files now live in the… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/content_renderer.gypi ('k') | content/renderer/renderer_clipboard_client.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/clipboard_client.h
===================================================================
--- content/renderer/clipboard_client.h (revision 207064)
+++ content/renderer/clipboard_client.h (working copy)
@@ -1,17 +1,17 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef WEBKIT_GLUE_CLIPBOARD_CLIENT_H_
-#define WEBKIT_GLUE_CLIPBOARD_CLIENT_H_
+#ifndef CONTENT_RENDERER_CLIPBOARD_CLIENT_H_
+#define CONTENT_RENDERER_CLIPBOARD_CLIENT_H_
#include "ui/base/clipboard/clipboard.h"
class GURL;
-namespace webkit_glue {
+namespace content {
-// Interface for the webkit glue embedder to implement to support clipboard.
+// Interface for the content embedder to implement to support clipboard.
class ClipboardClient {
public:
class WriteContext {
@@ -79,6 +79,7 @@
virtual WriteContext* CreateWriteContext() = 0;
};
-} // namespace webkit_glue
+} // namespace content
-#endif // WEBKIT_GLUE_CLIPBOARD_CLIENT_H_
+#endif // CONTENT_RENDERER_CLIPBOARD_CLIENT_H_
+
« no previous file with comments | « content/content_renderer.gypi ('k') | content/renderer/renderer_clipboard_client.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698